@@ -15,10 +15,11 @@ Including another URLconf
 """
 from django.conf.urls import url
 from django.contrib import admin
+from django.views.decorators.csrf import csrf_exempt
 
 from graphene_django.views import GraphQLView
 
 urlpatterns = [
     url(r"^admin/", admin.site.urls),
-    url(r"^graphql", GraphQLView.as_view(graphiql=True)),
+    url(r"^graphql", csrf_exempt(GraphQLView.as_view(graphiql=True))),
 ]
